@@ -1,29 +1,16 @@
-"""
-Copyright Astronomer, Inc.
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-"""
 from typing import Dict
 
 from airflow.decorators.base import get_unique_task_id
 from sqlalchemy import MetaData
 from sqlalchemy.sql.schema import Table as SqlaTable
 
-from astro.sql.operators.sql_decorator import SqlDecoratoratedOperator
+from astro.constants import Database
+from astro.sql.operators.sql_decorator import SqlDecoratedOperator
 from astro.sql.table import Table
+from astro.utils.database import get_database_from_conn_id
 
 
-class SqlTruncateOperator(SqlDecoratoratedOperator):
+class SqlTruncateOperator(SqlDecoratedOperator):
     def __init__(
         self,
         table: Table,
@@ -52,9 +39,13 @@ class SqlTruncateOperator(SqlDecoratoratedOperator):
         )
 
     def execute(self, context: Dict):
+        database = get_database_from_conn_id(self.table.conn_id)
+        if self.table.schema and database == Database.SQLITE:
+            metadata = MetaData()
+        else:
+            metadata = MetaData(schema=self.table.schema)
+
         engine = self.get_sql_alchemy_engine()
-        metadata = MetaData()
         table_sqla = SqlaTable(self.table.table_name, metadata, autoload_with=engine)
         self.sql = table_sqla.delete()
-
         super().execute(context)
